List of examples
~~~~~~~~~~~~~~~~

These pages are referenced by relative links in README.md.

.. toctree::
   :maxdepth: 0

   actions_usage.md
   example1.md
   example2.md
   test_example2_py.md
   directive1.md
   directive1_raw.md
   directive1_report_txt.md
   test_directive1_py.md
   directive2.md
   directive2_raw.md
   directive2_report_txt.md
   test_directive2_py.md
   directive3.md
   directive3_raw.md
   directive3_report_txt.md
   test_directive3_py.md
   my_markdown_file.md
   ../project.md
   setup.md
   test_setup_py.md
   setup_doctest.md
   test_setup_doctest_py.md
   inline_example.md
   test_inline_example_py.md
   project_test_py.md
